%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% File name: ComputeRPEMLossFunction.m
%
% Description: Computes the MIMO RPEM loss function using parameters
%              at the end of the run. See Ljung and Sderstrm
%					1983, pp. 185-186.
%
% Inputs: Input signals, parameters at the end of the run,
%         system output(s), dimensions of input, system and
%         outputs. 
%
% Outputs: Value of loss function.
%
% Author and copyright: Torbjrn Wigren
%                       Systems and Control
%                       Department of Information Technology
%                       Uppsala University
%                       Uppsala
%                       Sweden
%
% Revision log: Created 2003-06-08.
%
% Firm revision: revision 1.0, 2004-12-23.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%
% Compute residuals
%

residualError=y(:,1:N)-y_ms(:,1:N);

%
% Compute V
%

sum=0;
percentReady=0;
for t=1:N
   if round(t*100/N)>percentReady
      percentReady=round(t*100/N)
   end

   sum=sum+residualError(:,t)'*inv(Gamma)*residualError(:,t);
end

V=(1/2)*(1/N)*sum+(1/2)*log(det(Gamma))